@@ -1,3 +1,4 @@
+import * as _ from 'lodash';
 import { ProjectModel, PodModel, StorageClassModel } from '@console/internal/models';
 import { STORAGE_CLASSES, PROJECTS, PODS } from '.';
 
@@ -24,6 +25,8 @@ export enum StorageDashboardQuery {
   USED_CAPACITY = 'USED_CAPACITY',
   REQUESTED_CAPACITY = 'REQUESTED_CAPACITY',
   CEPH_CAPACITY_AVAILABLE = 'CEPH_CAPACITY_AVAILABLE',
+  POOL_CAPACITY_RATIO = 'POOL_CAPACITY_RATIO',
+  POOL_SAVED_CAPACITY = 'POOL_SAVED_CAPACITY',
 }
 
 export const INDEPENDENT_UTILIZATION_QUERIES = {
@@ -77,9 +80,9 @@ export const CAPACITY_BREAKDOWN_QUERIES = {
   [StorageDashboardQuery.STORAGE_CLASSES_BY_USED]:
     'sum(kubelet_volume_stats_used_bytes * on (namespace,persistentvolumeclaim) group_left(storageclass, provisioner) (kube_persistentvolumeclaim_info * on (storageclass) group_left(provisioner) kube_storageclass_info {provisioner=~"(.*rbd.csi.ceph.com)|(.*cephfs.csi.ceph.com)|(ceph.rook.io/block)"})) by (storageclass, provisioner)',
   [StorageDashboardQuery.PODS_TOTAL_USED]:
-    'sum(sum((kubelet_volume_stats_used_bytes * on (namespace,persistentvolumeclaim) group_right() kube_pod_spec_volumes_persistentvolumeclaims_info) * on (namespace,persistentvolumeclaim) group_left(storageclass, provisioner) (kube_persistentvolumeclaim_info * on (storageclass)  group_left(provisioner) kube_storageclass_info {provisioner=~"(.*rbd.csi.ceph.com)|(.*cephfs.csi.ceph.com)|(ceph.rook.io/block)"})) by (pod,namespace))',
+    'sum((kubelet_volume_stats_used_bytes * on (namespace,persistentvolumeclaim,node) group_right() (kube_pod_info * on(namespace, pod)  group_right(node) kube_pod_spec_volumes_persistentvolumeclaims_info)) * on(namespace,persistentvolumeclaim) group_left(provisioner) (kube_persistentvolumeclaim_info * on (storageclass)  group_left(provisioner) kube_storageclass_info {provisioner=~"(.*rbd.csi.ceph.com)|(.*cephfs.csi.ceph.com)|(ceph.rook.io/block)"}))',
   [StorageDashboardQuery.PODS_BY_USED]:
-    'sum((kubelet_volume_stats_used_bytes * on (namespace,persistentvolumeclaim) group_right() kube_pod_spec_volumes_persistentvolumeclaims_info) * on (namespace,persistentvolumeclaim) group_left(storageclass, provisioner) (kube_persistentvolumeclaim_info * on (storageclass)  group_left(provisioner) kube_storageclass_info {provisioner=~"(.*rbd.csi.ceph.com)|(.*cephfs.csi.ceph.com)|(ceph.rook.io/block)"})) by (pod,namespace)',
+    '(kubelet_volume_stats_used_bytes * on (namespace,persistentvolumeclaim,node) group_right() (kube_pod_info * on(namespace, pod)  group_right(node) kube_pod_spec_volumes_persistentvolumeclaims_info)) * on(namespace,persistentvolumeclaim) group_left(provisioner) (kube_persistentvolumeclaim_info * on (storageclass)  group_left(provisioner) kube_storageclass_info {provisioner=~"(.*rbd.csi.ceph.com)|(.*cephfs.csi.ceph.com)|(ceph.rook.io/block)"})',
   [StorageDashboardQuery.CEPH_CAPACITY_TOTAL]: 'ceph_cluster_total_bytes',
   [StorageDashboardQuery.CEPH_CAPACITY_USED]:
     'sum(kubelet_volume_stats_used_bytes * on (namespace,persistentvolumeclaim) group_left(storageclass, provisioner) (kube_persistentvolumeclaim_info * on (storageclass)  group_left(provisioner) kube_storageclass_info {provisioner=~"(.*rbd.csi.ceph.com)|(.*cephfs.csi.ceph.com)"}))',
@@ -87,6 +90,13 @@ export const CAPACITY_BREAKDOWN_QUERIES = {
     'max(ceph_pool_max_avail * on (pool_id) group_left(name)ceph_pool_metadata{name=~"(.*file.*)|(.*block.*)"})',
 };
 
+export const POOL_STORAGE_EFFICIENCY_QUERIES = {
+  [StorageDashboardQuery.POOL_CAPACITY_RATIO]:
+    'sum(ceph_bluestore_bluestore_compressed_original) / clamp_min(sum(ceph_bluestore_bluestore_compressed),1)',
+  [StorageDashboardQuery.POOL_SAVED_CAPACITY]:
+    '(sum(ceph_bluestore_bluestore_compressed_original) - sum(ceph_bluestore_bluestore_compressed))',
+};
+
 export const breakdownQueryMap = {
   [PROJECTS]: {
     model: ProjectModel,
@@ -197,3 +207,7 @@ export const utilizationPopoverQueryMap = [
 
 export const getPVCUsedCapacityQuery = (pvcName: string): string =>
   `kubelet_volume_stats_used_bytes{persistentvolumeclaim='${pvcName}'}`;
+
+export const osdDiskInfoMetric = _.template(
+  `ceph_disk_occupation{exported_instance=~'<%= nodeName %>'}`,
+);
