@@ -13,7 +13,6 @@ import { k8sCreate, K8sResourceKind, k8sUpdate, K8sVerb } from '@console/interna
 import { ServiceModel as KnServiceModel } from '@console/knative-plugin';
 import { getKnativeServiceDepResource } from '@console/knative-plugin/src/utils/create-knative-utils';
 import { SecretType } from '@console/internal/components/secrets/create-secret';
-import * as plugins from '@console/internal/plugins';
 import { history } from '@console/internal/components/utils';
 import { getRandomChars } from '@console/shared/src/utils';
 import {
@@ -35,6 +34,7 @@ import {
   Resources,
 } from './import-types';
 import { createPipelineForImportFlow } from './pipeline/pipeline-template-utils';
+import { Perspective } from '@console/plugin-sdk';
 
 export const generateSecret = () => {
   // http://stackoverflow.com/questions/105034/create-guid-uuid-in-javascript
@@ -71,13 +71,13 @@ export const createOrUpdateImageStream = (
   const {
     name,
     project: { name: namespace },
-    application: { name: application },
+    application: { name: applicationName },
     labels: userLabels,
     git: { url: repository, ref },
-    image: { tag },
+    image: { tag: selectedTag },
   } = formData;
   const imageStreamName = imageStreamData && imageStreamData.metadata.name;
-  const defaultLabels = getAppLabels(name, application, imageStreamName, tag);
+  const defaultLabels = getAppLabels({ name, applicationName, imageStreamName, selectedTag });
   const defaultAnnotations = { ...getGitAnnotations(repository, ref), ...getCommonAnnotations() };
   const newImageStream = {
     apiVersion: 'image.openshift.io/v1',
@@ -131,7 +131,7 @@ export const createOrUpdateBuildConfig = (
   const {
     name,
     project: { name: namespace },
-    application: { name: application },
+    application: { name: applicationName },
     git: { url: repository, type: gitType, ref = 'master', dir: contextDir, secret: secretName },
     docker: { dockerfilePath },
     image: { tag: selectedTag },
@@ -142,7 +142,7 @@ export const createOrUpdateBuildConfig = (
   const imageStreamName = imageStream && imageStream.metadata.name;
   const imageStreamNamespace = imageStream && imageStream.metadata.namespace;
 
-  const defaultLabels = getAppLabels(name, application, imageStreamName, selectedTag);
+  const defaultLabels = getAppLabels({ name, applicationName, imageStreamName, selectedTag });
   const defaultAnnotations = { ...getGitAnnotations(repository, ref), ...getCommonAnnotations() };
   let buildStrategyData;
 
@@ -233,8 +233,8 @@ export const createOrUpdateDeployment = (
   const {
     name,
     project: { name: namespace },
-    application: { name: application },
-    image: { ports, tag },
+    application: { name: applicationName },
+    image: { ports, tag: selectedTag },
     deployment: {
       env,
       replicas,
@@ -247,7 +247,7 @@ export const createOrUpdateDeployment = (
   } = formData;
 
   const imageStreamName = imageStream && imageStream.metadata.name;
-  const defaultLabels = getAppLabels(name, application, imageStreamName, tag);
+  const defaultLabels = getAppLabels({ name, applicationName, imageStreamName, selectedTag });
   const annotations = {
     ...getGitAnnotations(repository, ref),
     ...getCommonAnnotations(),
@@ -321,8 +321,8 @@ export const createOrUpdateDeploymentConfig = (
   const {
     name,
     project: { name: namespace },
-    application: { name: application },
-    image: { ports, tag },
+    application: { name: applicationName },
+    image: { ports, tag: selectedTag },
     deployment: { env, replicas, triggers },
     labels: userLabels,
     limits: { cpu, memory },
@@ -331,7 +331,7 @@ export const createOrUpdateDeploymentConfig = (
   } = formData;
 
   const imageStreamName = imageStream && imageStream.metadata.name;
-  const defaultLabels = getAppLabels(name, application, imageStreamName, tag);
+  const defaultLabels = getAppLabels({ name, applicationName, imageStreamName, selectedTag });
   const defaultAnnotations = { ...getGitAnnotations(repository, ref), ...getCommonAnnotations() };
   const podLabels = getPodLabels(name);
 
@@ -523,7 +523,7 @@ export const createOrUpdateResources = async (
     );
   }
 
-  if (!_.isEmpty(ports) || buildStrategy === 'Docker') {
+  if (!_.isEmpty(ports) || buildStrategy === 'Docker' || buildStrategy === 'Source') {
     const originalService = _.get(appResources, 'service.data');
     const service = createService(formData, imageStream, originalService);
     requests.push(
@@ -547,10 +547,12 @@ export const createOrUpdateResources = async (
   return Promise.all(requests);
 };
 
-export const handleRedirect = (project: string, perspective: string) => {
-  const perspectiveData = plugins.registry
-    .getPerspectives()
-    .find((item) => item.properties.id === perspective);
+export const handleRedirect = (
+  project: string,
+  perspective: string,
+  perspectiveExtensions: Perspective[],
+) => {
+  const perspectiveData = perspectiveExtensions.find((item) => item.properties.id === perspective);
   const redirectURL = perspectiveData.properties.getImportRedirectURL(project);
   history.push(redirectURL);
 };
