@@ -1,41 +1,36 @@
 import * as React from 'react';
 import { shallow, ShallowWrapper } from 'enzyme';
 import FormSection from '@console/dev-console/src/components/import/section/FormSection';
+import { useK8sWatchResources } from '@console/internal/components/utils/k8s-watch-hook';
 import KafkaSourceSection from '../KafkaSourceSection';
-import { EventSources } from '../../import-types';
 import KafkaSourceNetSection from '../KafkaSourceNetSection';
+import ServiceAccountDropdown from '../../../dropdowns/ServiceAccountDropdown';
 
 type KafkaSourceSectionProps = React.ComponentProps<typeof KafkaSourceSection>;
 
-jest.mock('formik', () => ({
-  useField: jest.fn(() => [{}, {}]),
-  useFormikContext: jest.fn(() => ({
-    setFieldValue: jest.fn(),
-    setFieldTouched: jest.fn(),
-    validateForm: jest.fn(),
-    values: {
-      type: 'KafkaSource',
-      data: {
-        kafkasource: {
-          bootstrapServers: [''],
-          topics: [''],
-        },
-      },
-    },
-  })),
+jest.mock('@console/internal/components/utils/k8s-watch-hook', () => ({
+  useK8sWatchResources: jest.fn(),
 }));
 describe('KafkaSourceSection', () => {
+  const title = 'Kafka Source';
   let wrapper: ShallowWrapper<KafkaSourceSectionProps>;
-  beforeEach(() => {
-    wrapper = shallow(<KafkaSourceSection />);
-  });
 
   it('should render KafkaSource FormSection with proper title', () => {
+    (useK8sWatchResources as jest.Mock).mockReturnValue({
+      kafkas: { data: [], loaded: true },
+      kafkatopics: { data: [], loaded: true },
+    });
+    wrapper = shallow(<KafkaSourceSection title={title} />);
     expect(wrapper.find(FormSection)).toHaveLength(1);
-    expect(wrapper.find(FormSection).props().title).toBe(EventSources.KafkaSource);
+    expect(wrapper.find(FormSection).props().title).toBe('Kafka Source');
   });
 
-  it('should render BootstrapServers and Topics fields', () => {
+  it('should render BootstrapServers and Topics fields with ', () => {
+    (useK8sWatchResources as jest.Mock).mockReturnValue({
+      kafkas: { data: [], loaded: true },
+      kafkatopics: { data: [], loaded: true },
+    });
+    wrapper = shallow(<KafkaSourceSection title={title} />);
     const bootstrapServersField = wrapper.find(
       '[data-test-id="kafkasource-bootstrapservers-field"]',
     );
@@ -47,11 +42,17 @@ describe('KafkaSourceSection', () => {
     expect(topicsField.props().required).toBeTruthy();
   });
 
-  it('should render consumergroup, netsection', () => {
+  it('should render consumergroup, netsection and service dropdown', () => {
+    (useK8sWatchResources as jest.Mock).mockReturnValue({
+      kafkas: { data: [], loaded: true },
+      kafkatopics: { data: [], loaded: true },
+    });
+    wrapper = shallow(<KafkaSourceSection title={title} />);
     const consumerGroupField = wrapper.find('[data-test-id="kafkasource-consumergroup-field"]');
     expect(consumerGroupField).toHaveLength(1);
     expect(consumerGroupField.props().required).toBeTruthy();
 
     expect(wrapper.find(KafkaSourceNetSection)).toHaveLength(1);
+    expect(wrapper.find(ServiceAccountDropdown)).toHaveLength(1);
   });
 });
